/* $Id: crires_parameter.h,v 1.7 2010/12/21 00:38:44 yjung Exp $
 *
 * This file is part of the CRIRES Pipeline
 * Copyright (C) 2002,2003 European Southern Observatory
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02111-1307  USA
 */

/*
 * $Author: yjung $
 * $Date: 2010/12/21 00:38:44 $
 * $Revision: 1.7 $
 * $Name: crire-2_1_1 $
 */

#ifndef CRIRES_PARAMETER_H
#define CRIRES_PARAMETER_H

/*-----------------------------------------------------------------------------
                                   Includes
 -----------------------------------------------------------------------------*/

#include <cpl.h>

/*-----------------------------------------------------------------------------
                                   Defines
 -----------------------------------------------------------------------------*/

/* The available recipe parameters */
/* None has the value 1, which makes the (mis)use of logical or detectable */

/* Integers */
#define CRIRES_PARAM_DISPLAY            ((crires_parameter) 1 <<  1)
#define CRIRES_PARAM_FWHM               ((crires_parameter) 1 <<  2)
#define CRIRES_PARAM_SEARCH_BOX         ((crires_parameter) 1 <<  3)
#define CRIRES_PARAM_MIN_MATCH          ((crires_parameter) 1 <<  4)
#define CRIRES_PARAM_ORDER              ((crires_parameter) 1 <<  5)
#define CRIRES_PARAM_HOR_SIZE           ((crires_parameter) 1 <<  6)
#define CRIRES_PARAM_SPEC_HSIZE         ((crires_parameter) 1 <<  7)
#define CRIRES_PARAM_CLOSING_HSIZE      ((crires_parameter) 1 <<  8)
#define CRIRES_PARAM_WL_NBSAMPLES       ((crires_parameter) 1 <<  9)
#define CRIRES_PARAM_WL_STARTY          ((crires_parameter) 1 <<  10)
#define CRIRES_PARAM_WL_STOPY           ((crires_parameter) 1 <<  11)
#define CRIRES_PARAM_DEGREE             ((crires_parameter) 1 <<  12)
#define CRIRES_PARAM_RON_SAMPLES        ((crires_parameter) 1 <<  13)
#define CRIRES_PARAM_RON_SZ             ((crires_parameter) 1 <<  14)
#define CRIRES_PARAM_NORM_STARTY        ((crires_parameter) 1 <<  15)
#define CRIRES_PARAM_NORM_STOPY         ((crires_parameter) 1 <<  16)
#define CRIRES_PARAM_EXTR_MODE          ((crires_parameter) 1 <<  17)
#define CRIRES_PARAM_CONFIG_MODE        ((crires_parameter) 1 <<  18)
#define CRIRES_PARAM_LINES_MODE         ((crires_parameter) 1 <<  19)
#define CRIRES_PARAM_PMIN               ((crires_parameter) 1 <<  20)
#define CRIRES_PARAM_PMAX               ((crires_parameter) 1 <<  21)

/* double */
#define CRIRES_PARAM_SIGMA              ((crires_parameter) 1 <<  22)
#define CRIRES_PARAM_YPOS               ((crires_parameter) 1 <<  23)
#define CRIRES_PARAM_KAPPA              ((crires_parameter) 1 <<  24)
#define CRIRES_PARAM_CLEAN_RATE         ((crires_parameter) 1 <<  25)
#define CRIRES_PARAM_WL_ERROR           ((crires_parameter) 1 <<  26)
#define CRIRES_PARAM_XC_LIMIT           ((crires_parameter) 1 <<  27)
#define CRIRES_PARAM_BPM_RATE           ((crires_parameter) 1 <<  28)
#define CRIRES_PARAM_TOT_NDIT           ((crires_parameter) 1 <<  29)
#define CRIRES_PARAM_WL_FACTOR          ((crires_parameter) 1 <<  30)
#define CRIRES_PARAM_EXPTIME            ((crires_parameter) 1 <<  31)
#define CRIRES_PARAM_KAPPA_SIGCLIP      ((crires_parameter) 1 <<  32)

/* string */
#define CRIRES_PARAM_WAVES              ((crires_parameter) 1 <<  33)
#define CRIRES_PARAM_REJECT             ((crires_parameter) 1 <<  34)
#define CRIRES_PARAM_SPEC_ZONE          ((crires_parameter) 1 <<  35)
#define CRIRES_PARAM_THRESHOLDS         ((crires_parameter) 1 <<  36)
#define CRIRES_PARAM_LINES              ((crires_parameter) 1 <<  37)
#define CRIRES_PARAM_COLLAPSE_METH      ((crires_parameter) 1 <<  38)
#define CRIRES_PARAM_COMB_USED          ((crires_parameter) 1 <<  39)

/* boolean */
#define CRIRES_PARAM_REFINE             ((crires_parameter) 1 <<  40)
#define CRIRES_PARAM_ONLYA              ((crires_parameter) 1 <<  41)
#define CRIRES_PARAM_ONLYB              ((crires_parameter) 1 <<  42)
#define CRIRES_PARAM_BLIND              ((crires_parameter) 1 <<  43)
#define CRIRES_PARAM_WL_LOG             ((crires_parameter) 1 <<  44)
#define CRIRES_PARAM_WL_NOLIMIT         ((crires_parameter) 1 <<  45)
#define CRIRES_PARAM_WL_CLEAN           ((crires_parameter) 1 <<  46)
#define CRIRES_PARAM_FORCE              ((crires_parameter) 1 <<  47)
#define CRIRES_PARAM_REPLACE            ((crires_parameter) 1 <<  48)
#define CRIRES_PARAM_CLEAN_FLAT         ((crires_parameter) 1 <<  49)
#define CRIRES_PARAM_FILL_BLANKS        ((crires_parameter) 1 <<  50)
#define CRIRES_PARAM_PLOT               ((crires_parameter) 1 <<  51)
#define CRIRES_PARAM_WL_MODEL           ((crires_parameter) 1 <<  52)
#define CRIRES_PARAM_ADJUST             ((crires_parameter) 1 <<  53)

/*-----------------------------------------------------------------------------
                                       Prototypes
 -----------------------------------------------------------------------------*/

typedef unsigned long long crires_parameter;

cpl_error_code crires_parameter_set(cpl_parameterlist *, const char *,
        crires_parameter);
cpl_boolean crires_parameterlist_get_bool(const cpl_parameterlist *,
        const char *, crires_parameter);
int crires_parameterlist_get_int(const cpl_parameterlist *,
        const char *, crires_parameter);
double crires_parameterlist_get_double(const cpl_parameterlist *,
        const char *, crires_parameter);
const char * crires_parameterlist_get_string(const cpl_parameterlist *,
        const char *, crires_parameter);

#endif
